==> haskell-xcb-types-0.7.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xcb-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.7.1
id: xcb-types-0.7.1-2b5d4efcaa71b2cf2ee77b139fd9c4b6
key: xcbty_FHb53fU21c9GZpaQvsrlt0
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.XCB Data.XCB.Types Data.XCB.Pretty Data.XCB.FromXML
hidden-modules: Data.XCB.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xcb-types-0.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/xcb-types-0.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/xcb-types-0.7.1
hs-libraries: HSxcb-types-0.7.1-FHb53fU21c9GZpaQvsrlt0
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    xml-1.3.14-47d6d03c8a900e03cf8951206101564b
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcb-types-0.7.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-xcb-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.7.1
id: xcb-types-0.7.1-0d701539531f1e7a50357ac242e80534
key: xcbty_Dc4CQEzuNY7C9ybI6f1sKk
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.XCB Data.XCB.Types Data.XCB.Pretty Data.XCB.FromXML
hidden-modules: Data.XCB.Utils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xcb-types-0.7.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/xcb-types-0.7.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/xcb-types-0.7.1
hs-libraries: HSxcb-types-0.7.1-Dc4CQEzuNY7C9ybI6f1sKk
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
    xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
